==> haskell-quickcheck-io-0.2.0-519-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-8Nu2yx67JRl98O33F9E0Py
key:                  quickcheck-io-0.2.0-8Nu2yx67JRl98O33F9E0Py
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  1bc7b72d2ce40c7ec171e7847a2ca94e
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-8Nu2yx67JRl98O33F9E0Py
depends:
    HUnit-1.6.2.0-7Y0VuWuCIsAKWjVqhc1VJN
    QuickCheck-2.14.2-JAfVoSJ1VKW3z92cRcZSMa base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-530-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-5Yvg2bsmNmTBGoX21S7vk2
key:                  quickcheck-io-0.2.0-5Yvg2bsmNmTBGoX21S7vk2
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  17a0ef587566f15230f74c9758919168
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-5Yvg2bsmNmTBGoX21S7vk2
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl
    QuickCheck-2.14.2-9XV9O7HSttLDBHWdDvT99R base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
